// FILENAME:	MI_Mars_3_SandD.cs
//
//------------------------------------------------------------------------------

$missionName = "MI_Mars_3_SandD";  // DM_Mars_Battle
exec("MercsIncMultiplayerStdLib.cs");
exec("MIConfigCosts.cs");

$MissionCycling::Stage0 = "MercsInc";

function setDefaultMissionOptions()
{
  $server::TeamPlay = true;
  $server::AllowDeathmatch = false;
  $server::AllowTeamPlay = true;	
	
  $server::AllowTeamRed = true;
  $server::AllowTeamBlue = false;
  $server::AllowTeamYellow = false;
  $server::AllowTeamPurple = false;
}


function onMissionStart()
{
  plutoSounds();
}


function onMissionLoad()
{
  $MIstateOfMission = 0;  // 0 = not started, 1 = in progress, 2 = victory, 3 = loss
  $MIinGamePlayers = 0;
  if($MItransportPercent == "") $MItransportPercent = 0.05;
  if($MIdifficulty == "") $MIdifficulty = 1;
  if($MIbountyPercent == "") $MIbountyPercent = 0.02;
  if($MItotalPay == "") $MItotalPay = 1000;
}


//======================


function player::onAdd(%player)
{
  %player.MIloggedIn = 0;
  %player.MIstartMission = 0;
}


function player::onRemove(%player)
{
  %count = (playerManager::getPlayerCount() - 1);
  if(%count == 0)
  {
    $MIstateOfMission = 3;
    schedule("missionEndConditionMet();", 1);
  }
  else Mercs::startCheck();
}


function vehicle::OnAdd(%vehicle)
{
  %player = playermanager::vehicleIDtoPlayerNum(%vehicle);
  if(%player == 0) return;
  setTeam(%vehicle, *IDSTR_TEAM_RED);

  if(%player.MIdied == 1)
  {
    damageobject(%vehicle, 50000);
    say(%player, 0, "You have already died.  Please wait for the mission to complete (your bonus will be forfeit if you quit early.");
    return;
  }

  if($MIstateOfMission != 0)
  {
    say(%player, 0, "You cannot join a mission in progress.  Please wait until the mission ends.");
    damageobject(%vehicle, 50000);
    return;
  }

  if(%player.MIloggedIn != 1)
  {
    damageobject(%vehicle, 50000);
    messagebox(%player, "Sorry, this mission has already launched.  Please wait until the battlegroup returns to the lobby.  Thank you for your patience.");
  }
  else
  {
    redrop(%vehicle);
    %vehicleCost = MIConfigCosts::checkvalue(%vehicle);
    %player.MIvehicleCost = %vehicleCost;
    if(%vehicleCost > (%player.MImoney + 1) )
    {
      messagebox(%player, "Your vehicle cost is $" @ %vehicleCost @ ".  You only have $" @ %player.MImoney @ " in your account.  Please select a less expensive vehicle.");
      damageobject(%vehicle, 50000);
    }
    else
    {
      %player.MItransportCost = round(%vehicleCost * $MItransportPercent);
      messagebox(%player, "Your vehicle cost is $" @ %vehicleCost @ ".  Transport fees will be $" @ %player.MItransportCost @ ".  Please log in again to confirm your selection.");
      Mercs::keepVehicleShutdown(%vehicle);
      %player.MIdied = 0;
    }
  }
}


function vehicle::OnDestroyed(%target, %attacker)
{
  if($MIstateOfMission == 0) return;

  %attackerPlayer = playerManager::vehicleIdToPlayerNum(%attacker);
  %targetPlayer = playerManager::vehicleIdToPlayerNum(%target);

  if(%targetPlayer != 0)
  {
    if(%targetPlayer.MIloggedIn != 1)
    {
      return;
    }
    else
    {
      say(0, 0, getName(%targetPlayer) @ " is down");
      %player.MIdied = 1;
      $MIinGamePlayers--;
      say(%targetPlayer, 0, "$" @ %targetPlayer.MIvehicleCost @ " fee for losing your vehicle.  Please remain in the vicinity until mission end to collect your bonus.");
      %fee = %targetPlayer.MIvehicleCost * -1;
      %targetPlayer.MItransportCost = 0;
      Mercs::addMoney(%targetPlayer, %fee);
      %targetPlayer.MIlostVehicle = 1;
    }
  }

  else
  {
    if(%attackerPlayer == 0) return;

    %points = round(MIConfigCosts::checkValue(%vehicle) * $MIbountyPercent);

    if(%target != %attacker)
    {
      %attackerPlayer.MIbounty = %attackerPlayer.MIbounty + %points;
      say(0, 0, getName(%attackerPlayer) @ " neutralized a Cybrid ($" @ %points @ " bounty).");
    }

    $MItargets--;
    if($MItargets < 1)
    {
      $MIstateOfMission = 2;
      say(0, 0, "Mission complete.");
      Mercs::endMission();
    }
  }

  if($MIinGamePlayers < 1)
  {
    $MIstateOfMission = 3;
    say(0, 0, "Mission failed!");
    $MItotalPay = 0;
    Mercs::endMission();
  }
}



//===================


function Mercs::addMoney(%player, %money)
{
  %player.MImoney = %player.MImoney + %money;
  if(%player.MImoney < 0) %player.MImoney = 0;
  $MIPlayerMoney[%player.MIid] = %player.MImoney;  
  Mercs::InscribePlayers();
}


function Mercs::endMission()
{
  %count = playerManager::getPlayerCount();
  if(%count != 0) Mercs::payouts();

  schedule("missionEndConditionMet();", 10);
}


function Mercs::inscribePlayers()
{
  $MIplaceHolder = "Mercenaries, Inc. Mission List";
  export("$MIplaceHolder", "multiplayer\\MercsIncPlayerList.cs", overwrite);
  fileWrite( "multiplayer\\MercsIncPlayerList.cs" , append, "");
  fileWrite( "multiplayer\\MercsIncPlayerList.cs" , append, "$MIPlayers = " @ $MIPlayers @ ";");

  for(%i=0; %i<$MIPlayers; %i++)
  {
    fileWrite( "multiplayer\\MercsIncPlayerList.cs" , append, "$MIPlayer[" @ %i @ "] = \"" @ $MIPlayer[%i] @ "\";");
    fileWrite( "multiplayer\\MercsIncPlayerList.cs" , append, "$MIPlayerMoney[" @ %i @ "] = " @ $MIPlayerMoney[%i] @ ";");
    fileWrite( "multiplayer\\MercsIncPlayerList.cs" , append, "$MIPlayerPassword[" @ %i @ "] = \"" @ $MIPlayerPassword[%i] @ "\";");
  }
}


function Mercs::keepVehicleShutdown(%vehicle)
{
  if($MIstateOfMission != 0)
  {
    order(%vehicle, shutdown, false);
    return;
  }

  order(%vehicle, shutdown, true);
  schedule("Mercs::keepVehicleShutdown(" @ %vehicle @ ", true);", 1);
}


function Mercs::payouts()
{
  %missionPay = $MItotalPay;
  %count = playerManager::getPlayerCount();

  %mercCount = 0;
  for(%i = 0; %i < %count; %i++)
  {
    %player = playerManager::getPlayerNum(%i);
    if(%player.MIloggedIn == 1) %mercCount++;
  }
  if(%mercCount != 1) %mercPlural = "s ";
   else %mercPlural = "";

  %missionPayPerPlayer = round(%missionPay / %mercCount);

  for(%i = 0; %i < %count; %i++)
  {
    %player = playerManager::getPlayerNum(%i);
    %player.MIstartMission = 0;

    %playerPayout = 0;
    %playerPayout = %missionPayPerPlayer;
    %playerPayout = %playerPayout + %player.MIbounty;
    %playerPayout = %playerPayout - %player.MItransportCost;
    Mercs::addMoney(%player, %playerPayout);

    if($MIstateOfMission == 2) %outCome = "Mission completed\n";
     else if($MIstateOfMission == 3) %outCome = "Mission failed\n\nNo mission pay\n";
    if(%playerPayout > 0) %missionNote = "$" @ %missionPay @ " total pay for " @ %mercCount @ " merc" @ %mercPlural @ " = $" @ %missionPayPerPlayer @ " split\n"; 
     else %missionNote = "";
    if(%player.MIbounty > 0) %bountyNote = "+$" @ %player.MIbounty @ " kill bounty\n";
     else %bountyNote = "";
    if(%player.MItransportCost > 0) %transportNote = "-$" @ %player.MItransportCost @ " transport fees\n";
     else %transportNote = "";
    if(%player.MIlostVehicle == 1 && %player.MIvehicleCost > 1 ) %lostVehNote = "-$" @ %player.MIvehicleCost @ " (lost vehicle)\n";
     else %lostVehNote = "";

    messagebox(%player, %outCome @ %missionNote @ %bountyNote @ %transportNote @ %lostVehNote @ "Total payout: $" @ %playerPayout @ 
         "\n Your new account: $" @ %player.MImoney);
  }
}


function Mercs::startCheck()
{
  %ready = 1;
  %waitingFor = 0;

  %count = playerManager::getPlayerCount();

  if(%count == 0)
  {
    Mercs::endMission();
  }

  for(%i = 0; %i < %count; %i++)
  {
    %player = playerManager::getPlayerNum(%i);
    if(%player.MIstartMission != 1)
    {
      %ready = 0;
      %waitingFor++;
    }
  }

  if(%ready == 0)
  {
    if(%waitingFor != 1) %plural = "s.";
     else %plural = ".";

    say(0, 0, "Waiting for " @ %waitingFor @ " player" @ %plural );
  }

  else
  {
    say(0, 0, "All pilots have logged in.  Initiating mission.");
    Mercs::startMission();
  }
}


function Mercs::startMission()                 // Testing
{
  $MIstateOfMission = 1;

  %count = playerManager::getPlayerCount();
  for(%i = 0; %i < %count; %i++)
  {
    %player = playerManager::getPlayerNum(%i);
    %vehicle = playerManager::playerNumToVehicleID(%player);
  }
  
  %player = playerManager::getPlayerNum(0);
  %vehicle = playerManager::playerNumToVehicleId(%player);
  %x = getPosition(%vehicle, x);
  %y = getPosition(%vehicle, y);

  $MItargets = randomInt(1, 3);

  for(%i=0; %i<$MItargets; %i++)
  {
    %herc = NewObject("Goadie", Herc, 21 ); 
    setTeam( %herc, *IDSTR_TEAM_PURPLE );
    setPilotId(%herc,28);

    %distance = 0;
    while(%distance < 200 || %distance > 400)
    {
      %x2 = randomInt(1000, 2000);
      %y2 = randomInt(-1700, -700);

      %xsqr = (%x - %x2) * (%x - %x2);
      %ysqr = (%y - %y2) * (%y - %y2);

      %distance = sqrt( %xsqr + %ysqr);
    }

    %z2 = getTerrainHeight(%x2, %y2);
    setPosition(%herc, %x2, %y2, %z2);

//    order( %herc, holdfire, true );
//    schedule( " order( " @ %herc @ ", holdfire, false);", 4 );

    order(%herc, shutdown, true);
  }
}

//===================


function remoteMercs::Login(%player, %password)
{
  if(%player.MIstartMission == 1) return;

  if(%player.MIloggedIn != 1)
  {
    messagebox(%player, "Sorry, this mission has already launched.  Please wait until the battlegroup returns to the lobby.  Thank you for your patience.");
  }
  else
  {
    $MIInGamePlayers++;
    %player.MIstartMission = 1;
    %player.MIbounty = 0;
    %player.MIlostVehicle = 0;
    say(0, 0, getName(%player) @ " has logged in.");
    Mercs::startCheck();
  }
}


//===================



function round(%number)
{
  %roundNum = %number;
  if(%number > 0)
  {
    %excess = (%number - floor(%number));
    if(%excess >= 0.5)
    {
      %roundNum = (floor(%number) + 1);
    }
    else
    {
      %roundNum = floor(%number);
    }
  }
  if(%number < 0)
  {
    %excess = (floor(%number) - %number);
    if(%excess <= 0.5)
    {
      %roundNum = floor(%number);
    }
    else
    {
      %roundNum = (floor(%number) - 1);
    }
   }
   return %roundNum;
}


Pilot Goadie
{
   id = 28;
   
   skill = 0.2;
   accuracy = 0.2;
   aggressiveness = 0.8;
   activateDist = 1000.0;
   deactivateBuff = 200.0;
   targetFreq = 2.0;
   trackFreq = 2.3;
   fireFreq = 2.0;
   LOSFreq = 1.2;
   orderFreq = 8.0;
};
