//------------------------------------------------------------------------------
//
// Mercenaries, Inc. Multiplayer standard library
// Severely abbreviated

//-----------------------------------------------
// Utility functions


// If this variable is set to true, when a teammate hits another teammate repeatedly, 
// he will be penalized. The offender's Herc will be shut down, his reactor and shields
// drained, and all of his ammo (energy too) drained. Once a player has offended, he
// will be on probation temporarily. The probation time depends on how bad (or many times)
// he has attacked his teammates. 
//
// When enabled, the offending player is notified with a text message that he is being
// penalized for team attacking.

$teamHittingPenalty = False;


function warp( %obj1, %obj2 )
{
   // set the position of obj1 to the position of obj2
   %obj2X = getPosition( %obj2, "x" );
   %obj2Y = getPosition( %obj2, "y" );
   %obj2Z = getPosition( %obj2, "z" );
   
   setPosition( %obj1, %obj2X, %obj2Y, %obj2Z );
}



// called by the create multiplayer shell
// to initialize the vehicle, component, and weapon
// list
function setDefaultMissionItems() 
{
}


///////////////////////////////////////////////////////////////////////////////////////////////////
// Handle annoying team hitters (would-be team killers)
///////////////////////////////////////////////////////////////////////////////////////////////////
$countdownFrequency = 1;
$probeFrequency = 1.5;
$teamHitPenalty = 7;
$allowableOffenses = 10;

function vehicle::onAttacked(%this, %attacker)
{
   if( $enableTeamHittingPenalty == True )
   {
      if($server::TeamPlay == true)
      {
         if( %this != %attacker )
         {
            if(getTeam(%this) == getTeam(%attacker))
            {
               if(dataRetrieve(%attacker, "onProbation") != True)
               {
                  dataStore(%attacker, "onProbation", True);
                  schedule("dataStore(" @ %attacker @ ", \"onProbation\", False);", $probeFrequency);         
                  dataStore(%attacker, "totalOffenses", (dataRetrieve(%attacker, "totalOffenses") + $teamHitPenalty));
                  
                  if( dataRetrieve(%attacker, "hasCountdownSpawned") != True)
                  {
                     countdownOffenses(%attacker);
                     dataStore(%attacker, "hasCountdownSpawned", True);
                  }

                  if( dataRetrieve(%attacker, "totalOffenses") >= $allowableOffenses )
                  {
                     violate(%attacker);
                     %player = playerManager::vehicleIdToPlayerNum(%attacker);
                     if(%player != 0)
                     {
                        say(%player, 1234, *IDMULT_SPANKED, "rules_violated.wav");
                     }
                  }
               }   
            }
         }
      }
   }
}

function countdownOffenses(%offender)
{
   if(dataRetrieve(%offender, "totalOffenses"))
   {
      dataStore(%offender, "totalOffenses", dataRetrieve(%offender, "totalOffenses") - 1);
      schedule("countdownOffenses(" @ %offender @ ");", $probeFrequency);
   }
   else
   {
      dataStore(%offender, "hasCountdownSpawned", False);
   }
} 
